//-------------------------------------------------------------------------------------------------
// <copyright file="proc2utl.cpp" company="Microsoft">
//    Copyright (c) Microsoft Corporation.  All rights reserved.
//    
//    The use and distribution terms for this software are covered by the
//    Common Public License 1.0 (http://opensource.org/licenses/cpl.php)
//    which can be found in the file CPL.TXT at the root of this distribution.
//    By using this software in any fashion, you are agreeing to be bound by
//    the terms of this license.
//    
//    You must not remove this notice, or any other, from this software.
// </copyright>
// 
// <summary>
//    Process helper functions that require PSAPI.DLL.
// </summary>
//-------------------------------------------------------------------------------------------------

#include "precomp.h"


/********************************************************************
 ProcFindAllIdsFromExeName() - returns an array of process ids that are running specified executable.

*******************************************************************/
extern "C" HRESULT DAPI ProcFindAllIdsFromExeName(
    __in LPCWSTR wzExeName,
    __out DWORD** ppdwProcessIds,
    __out DWORD* pcProcessIds
    )
{
    HRESULT hr = S_OK;
    DWORD cbProcessIds = sizeof(DWORD) * 50;
    DWORD cbReturned = 0;
    DWORD* pdwProcessIds = NULL;

    *ppdwProcessIds = NULL;
    *pcProcessIds = 0;

    pdwProcessIds = (DWORD*)MemAlloc(cbProcessIds, TRUE);
    ExitOnNull(pdwProcessIds, hr, E_OUTOFMEMORY, "Failed to allocate array for process IDs.");

    for (;;)
    {
        if (!::EnumProcesses(pdwProcessIds, cbProcessIds, &cbReturned))
        {
            ExitWithLastError(hr, "Failed to enumerate processes.");
        }

        if (cbReturned == cbProcessIds)
        {
            DWORD* pdwReAllocPids = NULL;
            cbProcessIds *= 2;
            pdwReAllocPids = (DWORD*)MemReAlloc(pdwProcessIds, cbProcessIds, TRUE);
            ExitOnNull(pdwReAllocPids, hr, E_OUTOFMEMORY, "Failed to re-allocate array for process IDs.");

            pdwProcessIds = pdwReAllocPids;
        }
        else
        {
            break;
        }
    }

    for (DWORD i = 0; i < cbReturned / sizeof(DWORD); ++i)
    {
        HANDLE hProcess = ::OpenProcess(PROCESS_QUERY_INFORMATION | PROCESS_VM_READ, FALSE, pdwProcessIds[i]);
        if (!hProcess)
        {
            continue;
        }

        DWORD count;
        HMODULE hm;
        if (!::EnumProcessModules(hProcess, &hm, sizeof(HMODULE), &count))
        {
            continue;
        }

        WCHAR wzExePath[MAX_PATH];
        if (!::GetModuleFileNameExW(hProcess, hm, wzExePath, MAX_PATH))
        {
            ExitWithLastError1(hr, "Failed to get module file name for process ID %d.", pdwProcessIds[i]);
        }

        LPCWSTR wzFileName = FileFromPath(wzExePath);
        if (0 == lstrcmpiW(wzFileName, wzExeName))
        {
            if (!*ppdwProcessIds)
            {
                *ppdwProcessIds = (DWORD*)MemAlloc(sizeof(DWORD), TRUE);
                ExitOnNull(ppdwProcessIds, hr, E_OUTOFMEMORY, "Failed to allocate array for returned process IDs.");
            }
            else
            {
                DWORD* pdwReAllocReturnedPids = NULL;
                pdwReAllocReturnedPids = (DWORD*)MemReAlloc(*ppdwProcessIds, sizeof(DWORD) * ((*pcProcessIds) + 1), TRUE);
                ExitOnNull(pdwReAllocReturnedPids, hr, E_OUTOFMEMORY, "Failed to re-allocate array for returned process IDs.");

                *ppdwProcessIds = pdwReAllocReturnedPids;
            }
            
            (*ppdwProcessIds)[*pcProcessIds] = pdwProcessIds[i];
            (*pcProcessIds)++;
        }

        ::CloseHandle(hProcess);
    }

LExit:
    if (pdwProcessIds)
    {
        MemFree(pdwProcessIds);
    }

    return hr;
}
