﻿//-----------------------------------------------------------------------
// <copyright file="QTests.cs" company="Microsoft">
//     Copyright (c) Microsoft Corporation.  All rights reserved.
//    
//    The use and distribution terms for this software are covered by the
//    Common Public License 1.0 (http://opensource.org/licenses/cpl.php)
//    which can be found in the file CPL.TXT at the root of this distribution.
//    By using this software in any fashion, you are agreeing to be bound by
//    the terms of this license.
//    
//    You must not remove this notice, or any other, from this software.
// </copyright>
// <summary>
//     Contains test methods for the QTests
// </summary>
//-----------------------------------------------------------------------

namespace Microsoft.Tools.WindowsInstallerXml.Test.Tests
{
    using System;
    using System.IO;
    using System.Reflection;
    using System.Text;

    using Microsoft.VisualStudio.TestTools.UnitTesting;
    using Microsoft.Tools.WindowsInstallerXml.Test;

    /// <summary>
    /// Contains test methods for the QTests
    /// </summary>
    [TestClass]
    public class QTests : WixTests
    {
        /// <summary>
        /// The location of the QTests
        /// </summary>
        private static readonly string testDirectory = Environment.ExpandEnvironmentVariables(@"%WIX_ROOT%\examples\test");

        /// <summary>
        /// A WixUnit object used to run the QTests
        /// </summary>
        private static WixUnit wixUnit;

        /// <summary>
        /// Initializes the classes WixUnit object
        /// </summary>
        /// <param name="testContext">A TestContext</param>
        [ClassInitialize]
        public static void ClassInitialize(TestContext testContext)
        {
            wixUnit = new WixUnit(QTests.testDirectory);
            wixUnit.VerboseOutput = true;
            wixUnit.EnvironmentVariables.Add("FLAVOR", "debug.coverage");
            wixUnit.TestFile = Path.Combine(QTests.testDirectory, "tests.xml");
        }

        [TestMethod]
        [Description("ActionText")]
        [Priority(2)]
        public void ActionText()
        {
            wixUnit.RunTest("ActionText");
        }

        [TestMethod]
        [Description("ActionScheduling")]
        [Priority(2)]
        public void ActionScheduling()
        {
            wixUnit.RunTest("ActionScheduling");
        }

        [TestMethod]
        [Description("AppPool")]
        [Priority(2)]
        public void AppPool()
        {
            wixUnit.RunTest("AppPool");
        }

        [TestMethod]
        [Description("AppPool.Wixout")]
        [Priority(2)]
        public void AppPool_Wixout()
        {
            wixUnit.RunTest("AppPool.Wixout");
        }

        [TestMethod]
        [Description("AppPool.Wixout.Complete")]
        [Priority(2)]
        public void AppPool_Wixout_Complete()
        {
            wixUnit.RunTest("AppPool.Wixout.Complete");
        }

        [TestMethod]
        [Description("AppSearch")]
        [Priority(2)]
        public void AppSearch()
        {
            wixUnit.RunTest("AppSearch");
        }

        [TestMethod]
        [Description("AppSearch.Invert")]
        [Priority(2)]
        public void AppSearch_Invert()
        {
            wixUnit.RunTest("AppSearch.Invert");
        }

        [TestMethod]
        [Description("Assembly_Bad")]
        [Priority(2)]
        public void Assembly_Bad()
        {
            wixUnit.RunTest("Assembly_Bad");
        }

        [TestMethod]
        [Description("Assembly_Module")]
        [Priority(2)]
        public void Assembly_Module()
        {
            wixUnit.RunTest("Assembly_Module");
        }

        [TestMethod]
        [Description("Assembly_Module_Vista_Culture")]
        [Priority(2)]
        public void Assembly_Module_Vista_Culture()
        {
            wixUnit.RunTest("Assembly_Module_Vista_Culture");
        }

        [TestMethod]
        [Description("Assembly_Product")]
        [Priority(2)]
        public void Assembly_Product()
        {
            wixUnit.RunTest("Assembly_Product");
        }

        [TestMethod]
        [Description("AssemblyVersion")]
        [Priority(2)]
        public void AssemblyVersion()
        {
            wixUnit.RunTest("AssemblyVersion");
        }

        [TestMethod]
        [Description("BadAssemblyVersion")]
        [Priority(2)]
        public void BadAssemblyVersion()
        {
            wixUnit.RunTest("BadAssemblyVersion");
        }

        [TestMethod]
        [Description("Bad_Else")]
        [Priority(2)]
        public void Bad_Else()
        {
            wixUnit.RunTest("Bad_Else");
        }

        [TestMethod]
        [Description("Bad_Elseif")]
        [Priority(2)]
        public void Bad_Elseif()
        {
            wixUnit.RunTest("Bad_Elseif");
        }

        [TestMethod]
        [Description("BadRegistry")]
        [Priority(2)]
        public void BadRegistry()
        {
            wixUnit.RunTest("BadRegistry");
        }

        [TestMethod]
        [Description("BadRegistry2")]
        [Priority(2)]
        public void BadRegistry2()
        {
            wixUnit.RunTest("BadRegistry2");
        }

        [TestMethod]
        [Description("BadXml")]
        [Priority(2)]
        public void BadXml()
        {
            wixUnit.RunTest("BadXml");
        }

        [TestMethod]
        [Description("Billboard")]
        [Priority(2)]
        public void Billboard()
        {
            wixUnit.RunTest("Billboard");
        }

        [TestMethod]
        [Description("BinaryTooLong")]
        [Priority(2)]
        public void BinaryTooLong()
        {
            wixUnit.RunTest("BinaryTooLong");
        }

        [TestMethod]
        [Description("Case_Sensitive_If")]
        [Priority(2)]
        public void Case_Sensitive_If()
        {
            wixUnit.RunTest("Case_Sensitive_If");
        }

        [TestMethod]
        [Description("Category")]
        [Priority(2)]
        public void Category()
        {
            wixUnit.RunTest("Category");
        }

        [TestMethod]
        [Description("CcpDrive")]
        [Priority(2)]
        public void CcpDrive()
        {
            wixUnit.RunTest("CcpDrive");
        }

        [TestMethod]
        [Description("CcpSearch")]
        [Priority(2)]
        public void CcpSearch()
        {
            wixUnit.RunTest("CcpSearch");
        }

        [TestMethod]
        [Description("Class")]
        [Priority(2)]
        public void Class()
        {
            wixUnit.RunTest("Class");
        }

        [TestMethod]
        [Description("Class.2")]
        [Priority(2)]
        public void Class_2()
        {
            wixUnit.RunTest("Class.2");
        }

        [TestMethod]
        [Description("Class.3")]
        [Priority(2)]
        public void Class_3()
        {
            wixUnit.RunTest("Class.3");
        }

        [TestMethod]
        [Description("Class.AppId")]
        [Priority(2)]
        public void Class_AppId()
        {
            wixUnit.RunTest("Class.AppId");
        }

        [TestMethod]
        [Description("CloseApps")]
        [Priority(2)]
        public void CloseApps()
        {
            wixUnit.RunTest("CloseApps");
        }

        [TestMethod]
        [Description("CloseApps.1")]
        [Priority(2)]
        public void CloseApps_1()
        {
            wixUnit.RunTest("CloseApps.1");
        }

        [TestMethod]
        [Description("CloseApps.2")]
        [Priority(2)]
        public void CloseApps_2()
        {
            wixUnit.RunTest("CloseApps.2");
        }

        [TestMethod]
        [Description("CompanionFile")]
        [Priority(2)]
        public void CompanionFile()
        {
            wixUnit.RunTest("CompanionFile");
        }

        [TestMethod]
        [Description("ComponentFloating")]
        [Priority(1)]
        public void ComponentFloating()
        {
            wixUnit.RunTest("ComponentFloating");
        }

        [TestMethod]
        [Description("ComponentFloating.2")]
        [Priority(2)]
        public void ComponentFloating_2()
        {
            wixUnit.RunTest("ComponentFloating.2");
        }

        [TestMethod]
        [Description("ComponentGroup")]
        [Priority(2)]
        public void ComponentGroup()
        {
            wixUnit.RunTest("ComponentGroup");
        }

        [TestMethod]
        [Description("ComponentGroupNesting")]
        [Priority(1)]
        public void ComponentGroupNesting()
        {
            wixUnit.RunTest("ComponentGroupNesting");
        }

        [TestMethod]
        [Description("Compression.Compressed")]
        [Priority(1)]
        public void Compression_Compressed()
        {
            wixUnit.RunTest("Compression.Compressed");
        }

        [TestMethod]
        [Description("Compression.Uncompressed")]
        [Priority(2)]
        public void Compression_Uncompressed()
        {
            wixUnit.RunTest("Compression.Uncompressed");
        }

        [TestMethod]
        [Description("Condition")]
        [Priority(2)]
        public void Condition()
        {
            wixUnit.RunTest("Condition");
        }

        [TestMethod]
        [Description("ConfigurableModule")]
        [Priority(2)]
        public void ConfigurableModule()
        {
            wixUnit.RunTest("ConfigurableModule");
        }

        [TestMethod]
        [Description("Consistency.Shortcut")]
        [Priority(2)]
        public void Consistency_Shortcut()
        {
            wixUnit.RunTest("Consistency.Shortcut");
        }

        [TestMethod]
        [Description("Consistency.IsolatedComponent")]
        [Priority(2)]
        public void Consistency_IsolatedComponent()
        {
            wixUnit.RunTest("Consistency.IsolatedComponent");
        }

        [TestMethod]
        [Description("CopyFile")]
        [Priority(2)]
        public void CopyFile()
        {
            wixUnit.RunTest("CopyFile");
        }

        [TestMethod]
        [Description("CustomAction")]
        [Priority(1)]
        public void CustomAction()
        {
            wixUnit.RunTest("CustomAction");
        }

        [TestMethod]
        [Description("CustomAction.BadWin64")]
        [Priority(2)]
        public void CustomAction_BadWin64()
        {
            wixUnit.RunTest("CustomAction.BadWin64");
        }

        [TestMethod]
        [Description("CustomAction.Bad")]
        [Priority(2)]
        public void CustomAction_Bad()
        {
            wixUnit.RunTest("CustomAction.Bad");
        }

        [TestMethod]
        [Description("CustomTable")]
        [Priority(2)]
        public void CustomTable()
        {
            wixUnit.RunTest("CustomTable");
        }

        [TestMethod]
        [Description("CustomTableBad")]
        [Priority(2)]
        public void CustomTableBad()
        {
            wixUnit.RunTest("CustomTableBad");
        }

        [TestMethod]
        [Description("CustomTableDropped")]
        [Priority(2)]
        public void CustomTableDropped()
        {
            wixUnit.RunTest("CustomTableDropped");
        }

        [TestMethod]
        [Description("DirectorySearch")]
        [Priority(2)]
        public void DirectorySearch()
        {
            wixUnit.RunTest("DirectorySearch");
        }

        [TestMethod]
        [Description("DirectX")]
        [Priority(2)]
        public void DirectX()
        {
            wixUnit.RunTest("DirectX");
        }

        [TestMethod]
        [Description("Driver")]
        [Priority(2)]
        public void Driver()
        {
            wixUnit.RunTest("Driver");
        }

        [TestMethod]
        [Description("DuplicateFiles")]
        [Priority(2)]
        public void DuplicateFiles()
        {
            wixUnit.RunTest("DuplicateFiles");
        }

        [TestMethod]
        [Description("EmbeddedUI")]
        [Priority(2)]
        public void EmbeddedUI()
        {
            wixUnit.RunTest("EmbeddedUI");
        }

        [TestMethod]
        [Description("EventLog.EventSource")]
        [Priority(2)]
        public void EventLog_EventSource()
        {
            wixUnit.RunTest("EventLog.EventSource");
        }

        [TestMethod]
        [Description("Extension")]
        [Priority(1)]
        public void Extension()
        {
            wixUnit.RunTest("Extension");
        }

        [TestMethod]
        [Description("ExtraICE.0")]
        [Priority(1)]
        public void ExtraICE_0()
        {
            wixUnit.RunTest("ExtraICE.0");
        }

        [TestMethod]
        [Description("FeatureGroup.0")]
        [Priority(1)]
        public void FeatureGroup_0()
        {
            wixUnit.RunTest("FeatureGroup.0");
        }

        [TestMethod]
        [Description("FeatureGroup.1")]
        [Priority(2)]
        public void FeatureGroup_1()
        {
            wixUnit.RunTest("FeatureGroup.1");
        }

        [TestMethod]
        [Description("FeatureGroup.BadDuplicate")]
        [Priority(2)]
        public void FeatureGroup_BadDuplicate()
        {
            wixUnit.RunTest("FeatureGroup.BadDuplicate");
        }

        [TestMethod]
        [Description("FeatureGroup.Empty")]
        [Priority(2)]
        public void FeatureGroup_Empty()
        {
            wixUnit.RunTest("FeatureGroup.Empty");
        }

        [TestMethod]
        [Description("FeatureGroupRef")]
        [Priority(1)]
        public void FeatureGroupRef()
        {
            wixUnit.RunTest("FeatureGroupRef");
        }

        [TestMethod]
        [Description("FeatureGroup.BadLoop")]
        [Priority(2)]
        public void FeatureGroup_BadLoop()
        {
            wixUnit.RunTest("FeatureGroup.BadLoop");
        }

        [TestMethod]
        [Description("FeatureRef_0")]
        [Priority(2)]
        public void FeatureRef_0()
        {
            wixUnit.RunTest("FeatureRef_0");
        }

        [TestMethod]
        [Description("FeatureRef_1")]
        [Priority(2)]
        public void FeatureRef_1()
        {
            wixUnit.RunTest("FeatureRef_1");
        }

        [TestMethod]
        [Description("FeatureRefSimple")]
        [Priority(2)]
        public void FeatureRefSimple()
        {
            wixUnit.RunTest("FeatureRefSimple");
        }

        [TestMethod]
        [Description("File_Module")]
        [Priority(2)]
        public void File_Module()
        {
            wixUnit.RunTest("File_Module");
        }

        [TestMethod]
        [Description("File_Product")]
        [Priority(2)]
        public void File_Product()
        {
            wixUnit.RunTest("File_Product");
        }

        [TestMethod]
        [Description("File_Bad")]
        [Priority(2)]
        public void File_Bad()
        {
            wixUnit.RunTest("File_Bad");
        }

        [TestMethod]
        [Description("FileDefaultValues")]
        [Priority(2)]
        public void FileDefaultValues()
        {
            wixUnit.RunTest("FileDefaultValues");
        }

        [TestMethod]
        [Description("FileDuplicate")]
        [Priority(2)]
        public void FileDuplicate()
        {
            wixUnit.RunTest("FileDuplicate");
        }

        [TestMethod]
        [Description("FileNoDiskId")]
        [Priority(2)]
        public void FileNoDiskId()
        {
            wixUnit.RunTest("FileNoDiskId");
        }

        [TestMethod]
        [Description("FileShare")]
        [Priority(2)]
        public void FileShare()
        {
            wixUnit.RunTest("FileShare");
        }

        [TestMethod]
        [Description("FileShare_Invalid")]
        [Priority(2)]
        public void FileShare_Invalid()
        {
            wixUnit.RunTest("FileShare_Invalid");
        }

        [TestMethod]
        [Description("FollowParent")]
        [Priority(2)]
        public void FollowParent()
        {
            wixUnit.RunTest("FollowParent");
        }

        [TestMethod]
        [Description("Foreach")]
        [Priority(2)]
        public void Foreach()
        {
            wixUnit.RunTest("Foreach");
        }

        [TestMethod]
        [Description("Fragment")]
        [Priority(1)]
        public void Fragment()
        {
            wixUnit.RunTest("Fragment");
        }

        [TestMethod]
        [Description("Fragment.0")]
        [Priority(2)]
        public void Fragment_0()
        {
            wixUnit.RunTest("Fragment.0");
        }

        [TestMethod]
        [Description("GeneratedShortFileNames")]
        [Priority(2)]
        public void GeneratedShortFileNames()
        {
            wixUnit.RunTest("GeneratedShortFileNames");
        }

        [TestMethod]
        [Description("GeneratedShortFileNamesCollide")]
        [Priority(2)]
        public void GeneratedShortFileNamesCollide()
        {
            wixUnit.RunTest("GeneratedShortFileNamesCollide");
        }

        [TestMethod]
        [Description("GuidGen")]
        [Priority(1)]
        public void GuidGen()
        {
            wixUnit.RunTest("GuidGen");
        }

        [TestMethod]
        [Description("GuidGenBadReg")]
        [Priority(2)]
        public void GuidGenBadReg()
        {
            wixUnit.RunTest("GuidGenBadReg");
        }

        [TestMethod]
        [Description("HarvestProj")]
        [Priority(1)]
        public void HarvestProj()
        {
            wixUnit.RunTest("HarvestProj");
        }

        [TestMethod]
        [Description("Icon")]
        [Priority(2)]
        public void Icon()
        {
            wixUnit.RunTest("Icon");
        }

        [TestMethod]
        [Description("If")]
        [Priority(1)]
        public void If()
        {
            wixUnit.RunTest("If");
        }

        [TestMethod]
        [Description("IgnoreModularization")]
        [Priority(2)]
        public void IgnoreModularization()
        {
            wixUnit.RunTest("IgnoreModularization");
        }

        [TestMethod]
        [Description("IniFile")]
        [Priority(2)]
        public void IniFile()
        {
            wixUnit.RunTest("IniFile");
        }

        [TestMethod]
        [Description("InstanceTransform")]
        [Priority(2)]
        public void InstanceTransform()
        {
            wixUnit.RunTest("InstanceTransform");
        }

        [TestMethod]
        [Description("InternetShortcuts")]
        [Priority(2)]
        public void InternetShortcuts()
        {
            wixUnit.RunTest("InternetShortcuts");
        }

        [TestMethod]
        [Description("LaunchConditions")]
        [Priority(2)]
        public void LaunchConditions()
        {
            wixUnit.RunTest("LaunchConditions");
        }

        [TestMethod]
        [Description("LaunchConditions.Invert")]
        [Priority(2)]
        public void LaunchConditions_Invert()
        {
            wixUnit.RunTest("LaunchConditions.Invert");
        }

        [TestMethod]
        [Description("Library")]
        [Priority(1)]
        public void Library()
        {
            wixUnit.RunTest("Library");
        }

        [TestMethod]
        [Description("Library.DuplicateSymbol")]
        [Priority(2)]
        public void Library_DuplicateSymbol()
        {
            wixUnit.RunTest("Library.DuplicateSymbol");
        }

        [TestMethod]
        [Description("Library.MultipleEntry")]
        [Priority(2)]
        public void Library_MultipleEntry()
        {
            wixUnit.RunTest("Library.MultipleEntry");
        }

        [TestMethod]
        [Description("Localize.en-us")]
        [Priority(2)]
        public void Localize_en_us()
        {
            wixUnit.RunTest("Localize.en-us");
        }

        [TestMethod]
        [Description("Localize.he-il")]
        [Priority(1)]
        public void Localize_he_il()
        {
            wixUnit.RunTest("Localize.he-il");
        }

        [TestMethod]
        [Description("Localize.empty")]
        [Priority(2)]
        public void Localize_empty()
        {
            wixUnit.RunTest("Localize.empty");
        }

        [TestMethod]
        [Description("Localize.FailIfMissing")]
        [Priority(2)]
        public void Localize_FailIfMissing()
        {
            wixUnit.RunTest("Localize.FailIfMissing");
        }

        [TestMethod]
        [Description("Localize.WixOut")]
        [Priority(2)]
        public void Localize_WixOut()
        {
            wixUnit.RunTest("Localize.WixOut");
        }

        [TestMethod]
        [Description("Localize.WixoutDelayLoc")]
        [Priority(2)]
        public void Localize_WixoutDelayLoc()
        {
            wixUnit.RunTest("Localize.WixoutDelayLoc");
        }

        [TestMethod]
        [Description("Localized.Merge")]
        [Priority(2)]
        public void Localized_Merge()
        {
            wixUnit.RunTest("Localized.Merge");
        }

        [TestMethod]
        [Description("Localize.Overridable")]
        [Priority(2)]
        public void Localize_Overridable()
        {
            wixUnit.RunTest("Localize.Overridable");
        }

        [TestMethod]
        [Description("Localize.Transform")]
        [Priority(2)]
        public void Localize_Transform()
        {
            wixUnit.RunTest("Localize.Transform");
        }

        [TestMethod]
        [Description("Merge_0_Module")]
        [Priority(1)]
        public void Merge_0_Module()
        {
            wixUnit.RunTest("Merge_0_Module");
        }

        [TestMethod]
        [Description("Merge_0_Product")]
        [Priority(1)]
        public void Merge_0_Product()
        {
            wixUnit.RunTest("Merge_0_Product");
        }

        [TestMethod]
        [Description("Merge_1_Module")]
        [Priority(2)]
        public void Merge_1_Module()
        {
            wixUnit.RunTest("Merge_1_Module");
        }

        [TestMethod]
        [Description("Merge_1_Product")]
        [Priority(2)]
        public void Merge_1_Product()
        {
            wixUnit.RunTest("Merge_1_Product");
        }

        [TestMethod]
        [Description("Gaming")]
        [Priority(2)]
        public void Gaming()
        {
            wixUnit.RunTest("Gaming");
        }

        [TestMethod]
        [Description("Merge_2_Product")]
        [Priority(2)]
        public void Merge_2_Product()
        {
            wixUnit.RunTest("Merge_2_Product");
        }

        [TestMethod]
        [Description("Merge_3_Product")]
        [Priority(2)]
        public void Merge_3_Product()
        {
            wixUnit.RunTest("Merge_3_Product");
        }

        [TestMethod]
        [Description("Merge_4")]
        [Priority(2)]
        public void Merge_4()
        {
            wixUnit.RunTest("Merge_4");
        }

        [TestMethod]
        [Description("Merge_5")]
        [Priority(2)]
        public void Merge_5()
        {
            wixUnit.RunTest("Merge_5");
        }

        [TestMethod]
        [Description("Mime")]
        [Priority(2)]
        public void Mime()
        {
            wixUnit.RunTest("Mime");
        }

        [TestMethod]
        [Description("Mime2")]
        [Priority(2)]
        public void Mime2()
        {
            wixUnit.RunTest("Mime2");
        }

        [TestMethod]
        [Description("MimeMap")]
        [Priority(2)]
        public void MimeMap()
        {
            wixUnit.RunTest("MimeMap");
        }

        [TestMethod]
        [Description("Miscellaneous")]
        [Priority(2)]
        public void Miscellaneous()
        {
            wixUnit.RunTest("Miscellaneous");
        }

        [TestMethod]
        [Description("Missing_Endif")]
        [Priority(2)]
        public void Missing_Endif()
        {
            wixUnit.RunTest("Missing_Endif");
        }

        [TestMethod]
        [Description("Missing_If_With_Else")]
        [Priority(2)]
        public void Missing_If_With_Else()
        {
            wixUnit.RunTest("Missing_If_With_Else");
        }

        [TestMethod]
        [Description("Missing_If_with_Elseif")]
        [Priority(2)]
        public void Missing_If_with_Elseif()
        {
            wixUnit.RunTest("Missing_If_with_Elseif");
        }

        [TestMethod]
        [Description("MSBuild_AfterBuild")]
        [Priority(2)]
        public void MSBuild_AfterBuild()
        {
            wixUnit.RunTest("MSBuild_AfterBuild");
        }

        [TestMethod]
        [Description("MSBuild_AfterClean")]
        [Priority(2)]
        public void MSBuild_AfterClean()
        {
            wixUnit.RunTest("MSBuild_AfterClean");
        }

        [TestMethod]
        [Description("MSBuild_AfterCompileAndLink")]
        [Priority(2)]
        public void MSBuild_AfterCompileAndLink()
        {
            wixUnit.RunTest("MSBuild_AfterCompileAndLink");
        }

        [TestMethod]
        [Description("MSBuild_AfterRebuild")]
        [Priority(2)]
        public void MSBuild_AfterRebuild()
        {
            wixUnit.RunTest("MSBuild_AfterRebuild");
        }

        [TestMethod]
        [Description("MSBuild_AfterResolveReferences")]
        [Priority(2)]
        public void MSBuild_AfterResolveReferences()
        {
            wixUnit.RunTest("MSBuild_AfterResolveReferences");
        }

        [TestMethod]
        [Description("MSBuild_BeforeBuild")]
        [Priority(2)]
        public void MSBuild_BeforeBuild()
        {
            wixUnit.RunTest("MSBuild_BeforeBuild");
        }

        [TestMethod]
        [Description("MSBuild_BeforeClean")]
        [Priority(2)]
        public void MSBuild_BeforeClean()
        {
            wixUnit.RunTest("MSBuild_BeforeClean");
        }

        [TestMethod]
        [Description("MSBuild_BeforeCompileAndLink")]
        [Priority(2)]
        public void MSBuild_BeforeCompileAndLink()
        {
            wixUnit.RunTest("MSBuild_BeforeCompileAndLink");
        }

        [TestMethod]
        [Description("MSBuild_BeforeRebuild")]
        [Priority(2)]
        public void MSBuild_BeforeRebuild()
        {
            wixUnit.RunTest("MSBuild_BeforeRebuild");
        }

        [TestMethod]
        [Description("MSBuild_BeforeResolveReferences")]
        [Priority(2)]
        public void MSBuild_BeforeResolveReferences()
        {
            wixUnit.RunTest("MSBuild_BeforeResolveReferences");
        }

        [TestMethod]
        [Description("MSBuild_CustomAfterWixTargets")]
        [Priority(2)]
        public void MSBuild_CustomAfterWixTargets()
        {
            wixUnit.RunTest("MSBuild_CustomAfterWixTargets");
        }

        [TestMethod]
        [Description("MSBuild_HeatDir")]
        [Priority(2)]
        public void MSBuild_HeatDir()
        {
            wixUnit.RunTest("MSBuild_HeatDir");
        }

        [TestMethod]
        [Description("MSBuild_HeatFile")]
        [Priority(2)]
        public void MSBuild_HeatFile()
        {
            wixUnit.RunTest("MSBuild_HeatFile");
        }

        [TestMethod]
        [Description("MSBuild_HeatProj")]
        [Priority(2)]
        public void MSBuild_HeatProj()
        {
            wixUnit.RunTest("MSBuild_HeatProj");
        }

        [TestMethod]
        [Description("MSBuild_Light")]
        [Priority(1)]
        public void MSBuild_Light()
        {
            wixUnit.RunTest("MSBuild_Light");
        }

        [TestMethod]
        [Description("MSBuild_MissingParameters_1")]
        [Priority(2)]
        public void MSBuild_MissingParameters_1()
        {
            wixUnit.RunTest("MSBuild_MissingParameters_1");
        }

        [TestMethod]
        [Description("MSBuild_MissingParameters_2")]
        [Priority(2)]
        public void MSBuild_MissingParameters_2()
        {
            wixUnit.RunTest("MSBuild_MissingParameters_2");
        }

        [TestMethod]
        [Description("MSBuild_MissingParameters_3")]
        [Priority(2)]
        public void MSBuild_MissingParameters_3()
        {
            wixUnit.RunTest("MSBuild_MissingParameters_3");
        }

        [TestMethod]
        [Description("MSBuild_MissingParameters_4")]
        [Priority(2)]
        public void MSBuild_MissingParameters_4()
        {
            wixUnit.RunTest("MSBuild_MissingParameters_4");
        }

        [TestMethod]
        [Description("MSBuild_PostBuildEvent")]
        [Priority(2)]
        public void MSBuild_PostBuildEvent()
        {
            wixUnit.RunTest("MSBuild_PostBuildEvent");
        }

        [TestMethod]
        [Description("MSBuild_PostBuildEventBuildVariables")]
        [Priority(2)]
        public void MSBuild_PostBuildEventBuildVariables()
        {
            wixUnit.RunTest("MSBuild_PostBuildEventBuildVariables");
        }

        [TestMethod]
        [Description("MSBuild_PreBuildEvent")]
        [Priority(2)]
        public void MSBuild_PreBuildEvent()
        {
            wixUnit.RunTest("MSBuild_PreBuildEvent");
        }

        [TestMethod]
        [Description("MSBuild_PreBuildEventBuildVariables")]
        [Priority(2)]
        public void MSBuild_PreBuildEventBuildVariables()
        {
            wixUnit.RunTest("MSBuild_PreBuildEventBuildVariables");
        }

        [TestMethod]
        [Description("MSBuild_ProjectRefs")]
        [Priority(1)]
        public void MSBuild_ProjectRefs()
        {
            wixUnit.RunTest("MSBuild_ProjectRefs");
        }

        [TestMethod]
        [Description("MSBuild_SolutionVars")]
        [Priority(2)]
        public void MSBuild_SolutionVars()
        {
            wixUnit.RunTest("MSBuild_SolutionVars");
        }

        [TestMethod]
        [Description("MSBuild_UserTargetsPath")]
        [Priority(2)]
        public void MSBuild_UserTargetsPath()
        {
            wixUnit.RunTest("MSBuild_UserTargetsPath");
        }

        [TestMethod]
        [Description("Msi45")]
        [Priority(2)]
        public void Msi45()
        {
            wixUnit.RunTest("Msi45");
        }

        [TestMethod]
        [Description("MultipleMedia")]
        [Priority(2)]
        public void MultipleMedia()
        {
            wixUnit.RunTest("MultipleMedia");
        }

        [TestMethod]
        [Description("NetFx")]
        [Priority(2)]
        public void NetFx()
        {
            wixUnit.RunTest("NetFx");
        }

        [TestMethod]
        [Description("ODBC")]
        [Priority(2)]
        public void ODBC()
        {
            wixUnit.RunTest("ODBC");
        }

        [TestMethod]
        [Description("ODBC.Module")]
        [Priority(2)]
        public void ODBC_Module()
        {
            wixUnit.RunTest("ODBC.Module");
        }

        [TestMethod]
        [Description("OSInfo")]
        [Priority(2)]
        public void OSInfo()
        {
            wixUnit.RunTest("OSInfo");
        }

        [TestMethod]
        [Description("Patch")]
        [Priority(2)]
        public void Patch()
        {
            wixUnit.RunTest("Patch");
        }

        [TestMethod]
        [Description("Patch.MajorUpgrade")]
        [Priority(1)]
        public void Patch_MajorUpgrade()
        {
            wixUnit.RunTest("Patch.MajorUpgrade");
        }

        [TestMethod]
        [Description("Patch.MinorUpgrade")]
        [Priority(2)]
        public void Patch_MinorUpgrade()
        {
            wixUnit.RunTest("Patch.MinorUpgrade");
        }

        [TestMethod]
        [Description("Patch.Bad")]
        [Priority(2)]
        public void Patch_Bad()
        {
            wixUnit.RunTest("Patch.Bad");
        }

        [TestMethod]
        [Description("Patch.ARP")]
        [Priority(2)]
        public void Patch_ARP()
        {
            wixUnit.RunTest("Patch.ARP");
        }

        [TestMethod]
        [Description("Patch.Localized")]
        [Priority(2)]
        public void Patch_Localized()
        {
            wixUnit.RunTest("Patch.Localized");
        }

        [TestMethod]
        [Description("PerfCounter")]
        [Priority(2)]
        public void PerfCounter()
        {
            wixUnit.RunTest("PerfCounter");
        }

        [TestMethod]
        [Description("MSBuild_WarnAsError")]
        [Priority(2)]
        public void MSBuild_WarnAsError()
        {
            wixUnit.RunTest("MSBuild_WarnAsError");
        }

        [TestMethod]
        [Description("PerfMon")]
        [Priority(2)]
        public void PerfMon()
        {
            wixUnit.RunTest("PerfMon");
        }

        [TestMethod]
        [Description("PerUser")]
        [Priority(2)]
        public void PerUser()
        {
            wixUnit.RunTest("PerUser");
        }

        [TestMethod]
        [Description("powershell.0")]
        [Priority(2)]
        public void powershell_0()
        {
            wixUnit.RunTest("powershell.0");
        }

        [TestMethod]
        [Description("powershell.1")]
        [Priority(2)]
        public void powershell_1()
        {
            wixUnit.RunTest("powershell.1");
        }

        [TestMethod]
        [Description("Preprocessor")]
        [Priority(1)]
        public void Preprocessor()
        {
            wixUnit.RunTest("Preprocessor");
        }

        [TestMethod]
        [Description("Preprocessor.WarningAndError")]
        [Priority(2)]
        public void Preprocessor_WarningAndError()
        {
            wixUnit.RunTest("Preprocessor.WarningAndError");
        }

        [TestMethod]
        [Description("QTExec")]
        [Priority(2)]
        public void QTExec()
        {
            wixUnit.RunTest("QTExec");
        }

        [TestMethod]
        [Description("Registry0")]
        [Priority(1)]
        public void Registry0()
        {
            wixUnit.RunTest("Registry0");
        }

        [TestMethod]
        [Description("Registry1")]
        [Priority(2)]
        public void Registry1()
        {
            wixUnit.RunTest("Registry1");
        }

        [TestMethod]
        [Description("Registry2")]
        [Priority(2)]
        public void Registry2()
        {
            wixUnit.RunTest("Registry2");
        }

        [TestMethod]
        [Description("RemoveFile_Good")]
        [Priority(2)]
        public void RemoveFile_Good()
        {
            wixUnit.RunTest("RemoveFile_Good");
        }

        [TestMethod]
        [Description("RemoveFile_Bad")]
        [Priority(2)]
        public void RemoveFile_Bad()
        {
            wixUnit.RunTest("RemoveFile_Bad");
        }

        [TestMethod]
        [Description("RemoveFolder_Good")]
        [Priority(2)]
        public void RemoveFolder_Good()
        {
            wixUnit.RunTest("RemoveFolder_Good");
        }

        [TestMethod]
        [Description("RemoveFolder_Bad")]
        [Priority(2)]
        public void RemoveFolder_Bad()
        {
            wixUnit.RunTest("RemoveFolder_Bad");
        }

        [TestMethod]
        [Description("RemoveFolder_Bad1")]
        [Priority(2)]
        public void RemoveFolder_Bad1()
        {
            wixUnit.RunTest("RemoveFolder_Bad1");
        }

        [TestMethod]
        [Description("RemoveReg")]
        [Priority(2)]
        public void RemoveReg()
        {
            wixUnit.RunTest("RemoveReg");
        }

        [TestMethod]
        [Description("SecureObjects")]
        [Priority(2)]
        public void SecureObjects()
        {
            wixUnit.RunTest("SecureObjects");
        }

        [TestMethod]
        [Description("SelfReg")]
        [Priority(2)]
        public void SelfReg()
        {
            wixUnit.RunTest("SelfReg");
        }

        [TestMethod]
        [Description("Service.Module")]
        [Priority(2)]
        public void Service_Module()
        {
            wixUnit.RunTest("Service.Module");
        }

        [TestMethod]
        [Description("ServiceConfig")]
        [Priority(2)]
        public void ServiceConfig()
        {
            wixUnit.RunTest("ServiceConfig");
        }

        [TestMethod]
        [Description("ShellExec")]
        [Priority(2)]
        public void ShellExec()
        {
            wixUnit.RunTest("ShellExec");
        }

        [TestMethod]
        [Description("ShellExec.2")]
        [Priority(2)]
        public void ShellExec_2()
        {
            wixUnit.RunTest("ShellExec.2");
        }

        [TestMethod]
        [Description("ShellExecBinary")]
        [Priority(2)]
        public void ShellExecBinary()
        {
            wixUnit.RunTest("ShellExecBinary");
        }

        [TestMethod]
        [Description("Shortcut")]
        [Priority(1)]
        public void Shortcut()
        {
            wixUnit.RunTest("Shortcut");
        }

        [TestMethod]
        [Description("Shortcut_Bad")]
        [Priority(2)]
        public void Shortcut_Bad()
        {
            wixUnit.RunTest("Shortcut_Bad");
        }

        [TestMethod]
        [Description("ShortNames")]
        [Priority(2)]
        public void ShortNames()
        {
            wixUnit.RunTest("ShortNames");
        }

        [TestMethod]
        [Description("ShortNames.1")]
        [Priority(2)]
        public void ShortNames_1()
        {
            wixUnit.RunTest("ShortNames.1");
        }

        [TestMethod]
        [Description("ShortNames.2")]
        [Priority(2)]
        public void ShortNames_2()
        {
            wixUnit.RunTest("ShortNames.2");
        }

        [TestMethod]
        [Description("SpecialStandardAction")]
        [Priority(2)]
        public void SpecialStandardAction()
        {
            wixUnit.RunTest("SpecialStandardAction");
        }

        [TestMethod]
        [Description("SqlScripts")]
        [Priority(2)]
        public void SqlScripts()
        {
            wixUnit.RunTest("SqlScripts");
        }

        [TestMethod]
        [Description("SqlString")]
        [Priority(2)]
        public void SqlString()
        {
            wixUnit.RunTest("SqlString");
        }

        [TestMethod]
        [Description("Streams")]
        [Priority(2)]
        public void Streams()
        {
            wixUnit.RunTest("Streams");
        }

        [TestMethod]
        [Description("StressCabinetCreation")]
        [Priority(2)]
        public void StressCabinetCreation()
        {
            wixUnit.RunTest("StressCabinetCreation");
        }

        [TestMethod]
        [Description("Suppress")]
        [Priority(2)]
        public void Suppress()
        {
            wixUnit.RunTest("Suppress");
        }

        [TestMethod]
        [Description("SuppressSequences")]
        [Priority(2)]
        public void SuppressSequences()
        {
            wixUnit.RunTest("SuppressSequences");
        }

        [TestMethod]
        [Description("SuppressWarn")]
        [Priority(2)]
        public void SuppressWarn()
        {
            wixUnit.RunTest("SuppressWarn");
        }

        [TestMethod]
        [Description("TextSrc")]
        [Priority(2)]
        public void TextSrc()
        {
            wixUnit.RunTest("TextSrc");
        }

        [TestMethod]
        [Description("TextSrc_2")]
        [Priority(2)]
        public void TextSrc_2()
        {
            wixUnit.RunTest("TextSrc_2");
        }

        [TestMethod]
        [Description("TextSrc_3")]
        [Priority(2)]
        public void TextSrc_3()
        {
            wixUnit.RunTest("TextSrc_3");
        }

        [TestMethod]
        [Description("Transform")]
        [Priority(1)]
        public void Transform()
        {
            wixUnit.RunTest("Transform");
        }

        [TestMethod]
        [Description("Transform.1")]
        [Priority(2)]
        public void Transform_1()
        {
            wixUnit.RunTest("Transform.1");
        }

        [TestMethod]
        [Description("Transform.2")]
        [Priority(2)]
        public void Transform_2()
        {
            wixUnit.RunTest("Transform.2");
        }

        [TestMethod]
        [Description("Transform.3")]
        [Priority(2)]
        public void Transform_3()
        {
            wixUnit.RunTest("Transform.3");
        }

        [TestMethod]
        [Description("Transform.Custom")]
        [Priority(2)]
        public void Transform_Custom()
        {
            wixUnit.RunTest("Transform.Custom");
        }

        [TestMethod]
        [Description("Transform.Mismatched")]
        [Priority(2)]
        public void Transform_Mismatched()
        {
            wixUnit.RunTest("Transform.Mismatched");
        }

        [TestMethod]
        [Description("TypeLib")]
        [Priority(2)]
        public void TypeLib()
        {
            wixUnit.RunTest("TypeLib");
        }

        [TestMethod]
        [Description("UI")]
        [Priority(1)]
        public void UI()
        {
            wixUnit.RunTest("UI");
        }

        [TestMethod]
        [Description("UI.AnotherOne")]
        [Priority(2)]
        public void UI_AnotherOne()
        {
            wixUnit.RunTest("UI.AnotherOne");
        }

        [TestMethod]
        [Description("UI.AnotherOne.Module")]
        [Priority(2)]
        public void UI_AnotherOne_Module()
        {
            wixUnit.RunTest("UI.AnotherOne.Module");
        }

        [TestMethod]
        [Description("UI.Fragmented")]
        [Priority(2)]
        public void UI_Fragmented()
        {
            wixUnit.RunTest("UI.Fragmented");
        }

        [TestMethod]
        [Description("UI.Lists")]
        [Priority(2)]
        public void UI_Lists()
        {
            wixUnit.RunTest("UI.Lists");
        }

        [TestMethod]
        [Description("UI.WiXUI_Advanced")]
        [Priority(2)]
        public void UI_WiXUI_Advanced()
        {
            wixUnit.RunTest("UI.WiXUI_Advanced");
        }

        [TestMethod]
        [Description("UI.WiXUI_FeatureTree")]
        [Priority(2)]
        public void UI_WiXUI_FeatureTree()
        {
            wixUnit.RunTest("UI.WiXUI_FeatureTree");
        }

        [TestMethod]
        [Description("UI.WiXUI_InstallDir")]
        [Priority(2)]
        public void UI_WiXUI_InstallDir()
        {
            wixUnit.RunTest("UI.WiXUI_InstallDir");
        }

        [TestMethod]
        [Description("UI.WiXUI_Minimal")]
        [Priority(2)]
        public void UI_WiXUI_Minimal()
        {
            wixUnit.RunTest("UI.WiXUI_Minimal");
        }

        [TestMethod]
        [Description("UI.WiXUI_Mondo")]
        [Priority(2)]
        public void UI_WiXUI_Mondo()
        {
            wixUnit.RunTest("UI.WiXUI_Mondo");
        }

        [TestMethod]
        [Description("UI.WiXUI_OverriddenLoc")]
        [Priority(2)]
        public void UI_WiXUI_OverriddenLoc()
        {
            wixUnit.RunTest("UI.WiXUI_OverriddenLoc");
        }

        [TestMethod]
        [Description("UI.WiXUI_ProgressText")]
        [Priority(2)]
        public void UI_WiXUI_ProgressText()
        {
            wixUnit.RunTest("UI.WiXUI_ProgressText");
        }

        [TestMethod]
        [Description("UI.WiXUI_Substituted")]
        [Priority(2)]
        public void UI_WiXUI_Substituted()
        {
            wixUnit.RunTest("UI.WiXUI_Substituted");
        }

        [TestMethod]
        [Description("UnrealTableOutput")]
        [Priority(2)]
        public void UnrealTableOutput()
        {
            wixUnit.RunTest("UnrealTableOutput");
        }

        [TestMethod]
        [Description("Upgrade")]
        [Priority(2)]
        public void Upgrade()
        {
            wixUnit.RunTest("Upgrade");
        }

        [TestMethod]
        [Description("Upgrade.Bad")]
        [Priority(2)]
        public void Upgrade_Bad()
        {
            wixUnit.RunTest("Upgrade.Bad");
        }

        [TestMethod]
        [Description("User")]
        [Priority(2)]
        public void User()
        {
            wixUnit.RunTest("User");
        }

        [TestMethod]
        [Description("UTF8")]
        [Priority(2)]
        public void UTF8()
        {
            wixUnit.RunTest("UTF8");
        }

        [TestMethod]
        [Description("VSHelp")]
        [Priority(2)]
        public void VSHelp()
        {
            wixUnit.RunTest("VSHelp");
        }

        [TestMethod]
        [Description("VSHelpMSM")]
        [Priority(2)]
        public void VSHelpMSM()
        {
            wixUnit.RunTest("VSHelpMSM");
        }

        [TestMethod]
        [Description("WebError")]
        [Priority(2)]
        public void WebError()
        {
            wixUnit.RunTest("WebError");
        }

        [TestMethod]
        [Description("WebFilter")]
        [Priority(2)]
        public void WebFilter()
        {
            wixUnit.RunTest("WebFilter");
        }

        [TestMethod]
        [Description("WebSite0")]
        [Priority(1)]
        public void WebSite0()
        {
            wixUnit.RunTest("WebSite0");
        }

        [TestMethod]
        [Description("WebSite1")]
        [Priority(2)]
        public void WebSite1()
        {
            wixUnit.RunTest("WebSite1");
        }
    }
}